@@ -16,6 +16,7 @@ import re
 import requests
 import requests_cache
 import sys
+from . import __version__
 
 try:
     from urllib.parse import quote as url_quote
@@ -48,10 +49,11 @@ else:
 
 
 if os.getenv('HOWDOI_DISABLE_SSL'):  # Set http instead of https
-    SEARCH_URL = 'http://www.google.com/search?q=site:stackoverflow.com%20{0}'
+    SEARCH_URL = 'http://www.google.com/search?q=site:{0}%20{1}'
 else:
-    SEARCH_URL = 'https://www.google.com/search?q=site:stackoverflow.com%20{0}'
+    SEARCH_URL = 'https://www.google.com/search?q=site:{0}%20{1}'
 
+URL = os.getenv('HOWDOI_URL') or 'stackoverflow.com'
 
 USER_AGENTS = ('Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:11.0) Gecko/20100101 Firefox/11.0',
                'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:22.0) Gecko/20100 101 Firefox/22.0',
@@ -93,7 +95,7 @@ def is_question(link):
 
 
 def get_links(query):
-    result = get_result(SEARCH_URL.format(url_quote(query)))
+    result = get_result(SEARCH_URL.format(URL, url_quote(query)))
     html = pq(result)
     return [a.attrib['href'] for a in html('.l')] or \
         [a.attrib['href'] for a in html('.r')('a')]
@@ -101,6 +103,8 @@ def get_links(query):
 
 def get_link_at_pos(links, position):
     links = [link for link in links if is_question(link)]
+    if not links:
+        return False
 
     if len(links) >= position:
         link = links[position-1]
@@ -134,6 +138,8 @@ def format_output(code, args):
 
 def get_answer(args, links):
     link = get_link_at_pos(links, args['pos'])
+    if not link:
+        return False
     if args.get('link'):
         return link
     page = get_result(link + '?answertab=votes')
@@ -166,8 +172,9 @@ def get_answer(args, links):
 
 def get_instructions(args):
     links = get_links(args['query'])
+
     if not links:
-        return ''
+        return False
     answers = []
     append_header = args['num_answers'] > 1
     initial_position = args['pos']
@@ -217,12 +224,18 @@ def get_parser():
     parser.add_argument('-n','--num-answers', help='number of answers to return', default=1, type=int)
     parser.add_argument('-C','--clear-cache', help='clear the cache',
                         action='store_true')
+    parser.add_argument('-v','--version', help='displays the current version of howdoi',
+                        action='store_true')
     return parser
 
 
 def command_line_runner():
     parser = get_parser()
     args = vars(parser.parse_args())
+    
+    if args['version']:
+        print(__version__)
+        return
 
     if args['clear_cache']:
         clear_cache()
